@@ -115,9 +115,12 @@ chunkedgraph_endpoints_v1 = {
     "handle_lineage_graph": pcg_v1 + "/table/{table_id}/lineage_graph_multiple",
     "past_id_mapping": pcg_v1 + "/table/{table_id}/past_id_mapping",
     "operation_details": pcg_v1 + "/table/{table_id}/operation_details",
+    "user_operations": pcg_v1 + "/table/{table_id}/user_operations",
     "is_latest_roots": pcg_v1 + "/table/{table_id}/is_latest_roots",
     "root_timestamps": pcg_v1 + "/table/{table_id}/root_timestamps",
     "delta_roots": pcg_v1 + "/table/{table_id}/delta_roots",
+    "preview_split": pcg_v1 + "/table/{table_id}/graph/split_preview",
+    "valid_nodes": pcg_v1 + "/table/{table_id}/valid_nodes",
 }
 
 chunkedgraph_api_versions = {
@@ -182,7 +185,9 @@ v1_auth = "{auth_server_address}/auth/api/v1"
 auth_endpoints_v1 = {
     "refresh_token": v1_auth + "/refresh_token",
     "create_token": v1_auth + "/create_token",
+    "get_tokens": v1_auth + "/user/token",
     "get_users": v1_auth + "/user",
+    "get_group_users": v1_auth + "/group/{group_id}/user",
 }
 
 auth_api_versions = {
