@@ -1,7 +1,7 @@
+import re
+import numpy as np
 from .base import (
-    ClientBaseWithDataset,
     ClientBaseWithDatastack,
-    _api_versions,
     _api_endpoints,
     handle_response,
 )
@@ -14,11 +14,9 @@ from .endpoints import (
 from .format_utils import (
     output_map_raw,
     output_map_precomputed,
-    output_map_graphene,
     format_raw,
 )
-import requests
-from warnings import warn
+
 
 SERVER_KEY = "i_server_address"
 
@@ -32,6 +30,8 @@ def InfoServiceClient(
     max_retries=None,
     pool_maxsize=None,
     pool_block=None,
+    over_client=None,
+    info_cache=None,
 ):
     if server_address is None:
         server_address = default_global_server_address
@@ -61,6 +61,8 @@ def InfoServiceClient(
         max_retries=max_retries,
         pool_maxsize=pool_maxsize,
         pool_block=pool_block,
+        over_client=over_client,
+        info_cache=info_cache,
     )
 
 
@@ -77,6 +79,8 @@ class InfoServiceClientV2(ClientBaseWithDatastack):
         max_retries=None,
         pool_maxsize=None,
         pool_block=None,
+        over_client=None,
+        info_cache=None,
     ):
         super(InfoServiceClientV2, self).__init__(
             server_address,
@@ -89,9 +93,13 @@ class InfoServiceClientV2(ClientBaseWithDatastack):
             max_retries=max_retries,
             pool_maxsize=pool_maxsize,
             pool_block=pool_block,
-
+            over_client=over_client,
         )
-        self.info_cache = dict()
+        if not info_cache:
+            self.info_cache = dict()
+        else:
+            self.info_cache = info_cache
+
         if datastack_name is not None:
             ds_info = self.get_datastack_info(datastack_name=datastack_name)
             self._aligned_volume_name = ds_info["aligned_volume"]["name"]
@@ -332,6 +340,37 @@ class InfoServiceClientV2(ClientBaseWithDatastack):
         for ds in self.info_cache.keys():
             self.get_datastack_info(datastack_name=ds, use_stored=False)
 
+    def viewer_resolution(self, datastack_name=None, use_stored=True):
+        """get the viewer resolution metadata for this datastack
+
+        Args:
+            datastack_name (_type_, optional): _description_. Defaults to None.
+              If None use the default one configured in the client
+            use_stored (bool, optional): _description_. Defaults to True.
+              Use the cached value, if False go get a new value from server
+        Returns:
+            np.array: voxel resolution as a len(3) np.array
+        """
+        vx = self._get_property(
+            "viewer_resolution_x",
+            datastack_name=datastack_name,
+            use_stored=use_stored,
+            format_for="raw",
+        )
+        vy = self._get_property(
+            "viewer_resolution_y",
+            datastack_name=datastack_name,
+            use_stored=use_stored,
+            format_for="raw",
+        )
+        vz = self._get_property(
+            "viewer_resolution_z",
+            datastack_name=datastack_name,
+            use_stored=use_stored,
+            format_for="raw",
+        )
+        return np.array([vx, vy, vz])
+
     def viewer_site(self, datastack_name=None, use_stored=True):
         """Get the base Neuroglancer URL for the dataset"""
         return self._get_property(
@@ -341,6 +380,56 @@ class InfoServiceClientV2(ClientBaseWithDatastack):
             format_for="raw",
         )
 
+    def image_cloudvolume(self, **kwargs):
+        """Generate a cloudvolume instance based on the image source, using authentication if needed and
+        sensible default values for reading CAVE resources. By default, fill_missing is True and bounded
+        is False. All keyword arguments are passed onto the CloudVolume initialization function, and defaults
+        can be overridden.
+
+        Requires cloudvolume to be installed, which is not included by default.
+        """
+        return self._make_cloudvolume(self.image_source(), **kwargs)
+
+    def segmentation_cloudvolume(self, use_client_secret=True, **kwargs):
+        """Generate a cloudvolume instance based on the segmentation source, using authentication if needed and
+        sensible default values for reading CAVE resources. By default, fill_missing is True and bounded
+        is False. All keyword arguments are passed onto the CloudVolume initialization function, and defaults
+        can be overridden.
+
+        Requires cloudvolume to be installed, which is not included by default.
+        """
+        return self._make_cloudvolume(
+            self.segmentation_source(), use_client_secret=use_client_secret, **kwargs
+        )
+
+    def _make_cloudvolume(self, cloudpath, use_client_secret=True, **kwargs):
+        try:
+            import cloudvolume
+        except:
+            raise ImportError(
+                "Could not import cloudvolume. Make sure it is installed. See https://pypi.org/project/cloud-volume for more info."
+            )
+
+        use_https = kwargs.pop("use_https", True)
+        bounded = kwargs.pop("bounded", False)
+        fill_missing = kwargs.pop("fill_missing", True)
+
+        if re.search("^graphene", cloudpath) and use_client_secret:
+            # Authentication header is "Authorization {token}"
+            secrets = {"token": self.session.headers.get("Authorization").split(" ")[1]}
+        else:
+            secrets = None
+
+        cv = cloudvolume.CloudVolume(
+            cloudpath,
+            use_https=use_https,
+            fill_missing=fill_missing,
+            bounded=bounded,
+            secrets=secrets,
+            **kwargs,
+        )
+        return cv
+
 
 client_mapping = {
     2: InfoServiceClientV2,
