@@ -401,23 +401,27 @@ class MaterializatonClientV2(ClientBase):
 
     @cached(cache=TTLCache(maxsize=100, ttl=60 * 60 * 12))
     def get_table_metadata(
-        self, table_name: str, datastack_name=None, version: int = None
+        self, table_name: str, 
+        datastack_name=None, 
+        version: int = None,
+        log_warning: bool = True
     ):
         """Get metadata about a table
 
-        Parameters
-        ----------
-        table_name (str):
-            name of table to mark for deletion
-        datastack_name: str or None, optional,
-            Name of the datastack_name.
-            If None, uses the one specified in the client.
+        Args:
+            table_name (str):
+                name of table to mark for deletion
+            datastack_name: str or None, optional,
+                Name of the datastack_name.
+                If None, uses the one specified in the client.
+            version (int, optional): 
+                version to get. If None, uses the one specified in the client.
+            log_warning (bool, optional): 
+                whether to print out warnings to the logger. 
+                Defaults to True.
 
-
-        Returns
-        -------
-        json
-            metadata about table
+        Returns:
+            dict: metadata dictionary for table
         """
         if datastack_name is None:
             datastack_name = self.datastack_name
@@ -431,7 +435,7 @@ class MaterializatonClientV2(ClientBase):
         url = self._endpoints["metadata"].format_map(endpoint_mapping)
 
         response = self.session.get(url)
-        metadata_d = handle_response(response)
+        metadata_d = handle_response(response, log_warning=log_warning)
         vx = metadata_d.pop("voxel_resolution_x", None)
         vy = metadata_d.pop("voxel_resolution_y", None)
         vz = metadata_d.pop("voxel_resolution_z", None)
@@ -500,6 +504,7 @@ class MaterializatonClientV2(ClientBase):
                 table_name=table,
                 datastack_name=datastack_name,
                 version=materialization_version,
+                log_warning=False
             )
             if md["reference_table"] is None:
                 target_table = None
@@ -628,7 +633,6 @@ class MaterializatonClientV2(ClientBase):
             offset,
             limit,
         )
-
         response = self.session.post(
             url,
             data=json.dumps(data, cls=BaseEncoder),
@@ -651,7 +655,7 @@ class MaterializatonClientV2(ClientBase):
                             "desired resolution needs to be of length 3, for xyz"
                         )
                     vox_res = self.get_table_metadata(
-                        table, datastack_name, materialization_version
+                        table, datastack_name, materialization_version, log_warning=False
                     )["voxel_resolution"]
                     df = convert_position_columns(df, vox_res, desired_resolution)
             if metadata:
@@ -1029,9 +1033,29 @@ class MaterializatonClientV2(ClientBase):
             # make sure the materialization's are increasing in ID/time
             for md in sorted(mds, key=lambda x: x["id"]):
                 ts = md["time_stamp"]
-                if timestamp > ts:
+                if timestamp >= ts:
                     materialization_version = md["version"]
-                    timestamp_start = ts
+                    if timestamp == ts:
+                        # If timestamp equality to a version, use the standard query_table.
+                        return self.query_table(
+                            table=table,
+                            filter_in_dict=filter_in_dict,
+                            filter_out_dict=filter_out_dict,
+                            filter_equal_dict=filter_equal_dict,
+                            filter_spatial_dict=filter_spatial_dict,
+                            select_columns=select_columns,
+                            offset=offset,
+                            limit=limit,
+                            datastack_name=datastack_name,
+                            split_positions=split_positions,
+                            materialization_version=materialization_version,
+                            metadata=metadata,
+                            merge_reference=merge_reference,
+                            desired_resolution=desired_resolution,
+                            return_df=True,
+                        )
+                    else:
+                        timestamp_start = ts
             # if none of the available versions are before
             # this timestamp, then we cannot support the query
             if materialization_version is None:
@@ -1124,6 +1148,7 @@ class MaterializatonClientV2(ClientBase):
                         table_name=table,
                         datastack_name=datastack_name,
                         version=materialization_version,
+                        log_warning=False
                     )["voxel_resolution"]
                     df = convert_position_columns(df, vox_res, desired_resolution)
             if not split_positions:
@@ -1279,7 +1304,7 @@ class MaterializatonClientV2(ClientBase):
         }
         if not join_query:
             attrs["join_query"] = False
-            meta = self.get_table_metadata(tables[0])
+            meta = self.get_table_metadata(tables[0], log_warning=False)
             for k, v in meta.items():
                 if re.match("^table", k):
                     attrs[k] = v
@@ -1297,7 +1322,7 @@ class MaterializatonClientV2(ClientBase):
                 suffixes = ["_x", "_y"]
             for (tname, jcol), s in zip(tables, suffixes):
                 table_attrs[tname] = {}
-                meta = self.get_table_metadata(tname)
+                meta = self.get_table_metadata(tname, log_warning=False)
                 for k, v in meta.items():
                     if re.match("^table", k):
                         table_attrs[tname][k] = v
